Provides a non-blocking Mutex.

Where a mutex would block, we yield execution.
This can be considered an async version of atomiclock.
Provides a non-blocking Mutex.

Where a mutex would block, we yield execution.
This can be considered an async version of atomiclock.